@@ -1,22 +1,5 @@
-# ***** BEGIN GPL LICENSE BLOCK *****
-#
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software Foundation,
-# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ***** END GPL LICENCE BLOCK *****
-#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
 # -----------------------------------------------------------------------
 # Author: Alan Odom (Clockmender), Rune Morling (ermo) Copyright (c) 2019
 # -----------------------------------------------------------------------
@@ -83,7 +66,7 @@ PDT_FeatureError = pdt_exception.FeatureError
 
 
 class PDT_OT_CommandReRun(Operator):
-    """Repeat Current Displayed Command."""
+    """Repeat Current Displayed Command"""
 
     bl_idname = "pdt.command_rerun"
     bl_label = "Re-run Current Command"
@@ -220,9 +203,9 @@ def command_run(self, context):
     mode = command[1].lower()
     if (
             (operation == "F" and mode not in {"v", "e", "i"})
-            or (operation in {"D", "E"} and mode not in {"d", "i"})
+            or (operation in {"D", "E"} and mode not in {"d", "i", "n"}) #new
             or (operation == "M" and mode not in {"a", "d", "i", "p", "o", "x", "y", "z"})
-            or (operation not in {"D", "E", "F", "M"} and mode not in {"a", "d", "i", "p"})
+            or (operation not in {"D", "E", "F", "M"} and mode not in {"a", "d", "i", "p", "n"}) #new
         ):
         pg.error = f"'{mode}' {PDT_ERR_NON_VALID} '{operation}'"
         context.window_manager.popup_menu(oops, title="Error", icon="ERROR")
@@ -322,15 +305,15 @@ def pdt_help(self, context):
     label = self.layout.label
     label(text="Primary Letters (Available Secondary Letters):")
     label(text="")
-    label(text="C: Cursor (a, d, i, p)")
-    label(text="D: Duplicate Geometry (d, i)")
-    label(text="E: Extrude Geometry (d, i)")
+    label(text="C: Cursor (a, d, i, p, v)")
+    label(text="D: Duplicate Geometry (d, i, v)")
+    label(text="E: Extrude Geometry (d, i, v)")
     label(text="F: Fillet (v, e, i)")
-    label(text="G: Grab (Move) (a, d, i, p)")
-    label(text="N: New Vertex (a, d, i, p)")
+    label(text="G: Grab (Move) (a, d, i, p, v)")
+    label(text="N: New Vertex (a, d, i, p, v)")
     label(text="M: Maths Functions (a, d, p, o, x, y, z)")
-    label(text="P: Pivot Point (a, d, i, p)")
-    label(text="V: Extrude Vertice Only (a, d, i, p)")
+    label(text="P: Pivot Point (a, d, i, p, v)")
+    label(text="V: Extrude Vertice Only (a, d, i, p, v)")
     label(text="S: Split Edges (a, d, i, p)")
     label(text="?: Quick Help")
     label(text="")
@@ -341,6 +324,8 @@ def pdt_help(self, context):
     label(text="d: Delta (Relative) Coordinates, e.g. 0.5,0,1.2")
     label(text="i: Directional (Polar) Coordinates e.g. 2.6,45")
     label(text="p: Percent e.g. 67.5")
+    label(text="n: Work in View Normal Axis")
+    label(text="")
     label(text="- Fillet Options:")
     label(text="v: Fillet Vertices")
     label(text="e: Fillet Edges")
@@ -438,6 +423,19 @@ def command_parse(context):
         except ValueError:
             values[ind] = "0.0"
         ind = ind + 1
+    if mode == "n":
+        # View relative mode
+        if pg.plane == "XZ":
+            values = [0.0, values[0], 0.0]
+        elif pg.plane == "YZ":
+            values = [values[0], 0.0, 0.0]
+        elif pg.plane == "XY":
+            values = [0.0, 0.0, values[0]]
+        else:
+            if "-" in values[0]:
+                values = [0.0, 0.0, values[0][1:]]
+            else:
+                values = [0.0, 0.0, f"-{values[0]}"]
     # Apply System Rounding
     decimal_places = context.preferences.addons[__package__].preferences.pdt_input_round
     values_out = [str(round(float(v), decimal_places)) for v in values]
@@ -450,7 +448,7 @@ def command_parse(context):
         mode_sel = 'SEL'
 
     if mode == "a" and operation not in {"C", "P"}:
-        # Place new Vetex, or Extrude Vertices by Absolute Coords.
+        # Place new Vertex, or Extrude Vertices by Absolute Coords.
         if mode_sel == 'REL':
             pg.select = 'SEL'
             mode_sel = 'SEL'
@@ -507,7 +505,7 @@ def move_cursor_pivot(context, pg, operation, mode, obj, verts, values):
     """
 
     # Absolute/Global Coordinates, or Delta/Relative Coordinates
-    if mode in {"a", "d"}:
+    if mode in {"a", "d", "n"}:
         try:
             vector_delta = vector_build(context, pg, obj, operation, values, 3)
         except:
@@ -537,8 +535,8 @@ def move_cursor_pivot(context, pg, operation, mode, obj, verts, values):
             scene.cursor.location = vector_delta
         elif operation == "P":
             pg.pivot_loc = vector_delta
-    elif mode in {"d", "i"}:
-        if pg.plane == "LO" and mode == "d":
+    elif mode in {"d", "i", "n"}:
+        if pg.plane == "LO" and mode in  {"d", "n"}:
             vector_delta = view_coords(vector_delta.x, vector_delta.y, vector_delta.z)
         elif pg.plane == "LO" and mode == "i":
             vector_delta = view_dir(pg.distance, pg.angle)
@@ -598,7 +596,7 @@ def move_entities(context, pg, operation, mode, obj, bm, verts, values):
         except:
             raise PDT_InvalidVector
         if obj.mode == "EDIT":
-            for v in verts:
+            for v in [v for v in bm.verts if v.select]:
                 v.co = vector_delta - obj_loc
             bmesh.ops.remove_doubles(
                 bm, verts=[v for v in bm.verts if v.select], dist=0.0001
@@ -607,8 +605,8 @@ def move_entities(context, pg, operation, mode, obj, bm, verts, values):
             for ob in context.view_layer.objects.selected:
                 ob.location = vector_delta
 
-    elif mode in {"d", "i"}:
-        if mode == "d":
+    elif mode in {"d", "i", "n"}:
+        if mode in {"d", "n"}:
             # Delta/Relative Coordinates
             try:
                 vector_delta = vector_build(context, pg, obj, operation, values, 3)
@@ -621,7 +619,7 @@ def move_entities(context, pg, operation, mode, obj, bm, verts, values):
             except:
                 raise PDT_InvalidVector
 
-        if pg.plane == "LO" and mode == "d":
+        if pg.plane == "LO" and mode in {"d", "n"}:
             vector_delta = view_coords(vector_delta.x, vector_delta.y, vector_delta.z)
         elif pg.plane == "LO" and mode == "i":
             vector_delta = view_dir(pg.distance, pg.angle)
@@ -678,7 +676,7 @@ def add_new_vertex(context, pg, operation, mode, obj, bm, verts, values):
             raise PDT_InvalidVector
         new_vertex = bm.verts.new(vector_delta - obj_loc)
     # Delta/Relative Coordinates
-    elif mode == "d":
+    elif mode in  {"d", "n"}:
         try:
             vector_delta = vector_build(context, pg, obj, operation, values, 3)
         except:
@@ -852,7 +850,7 @@ def extrude_vertices(context, pg, operation, mode, obj, obj_loc, bm, verts, valu
             bm, verts=[v for v in bm.verts if v.select], dist=0.0001
         )
     # Delta/Relative Coordinates
-    elif mode == "d":
+    elif mode in {"d", "n"}:
         try:
             vector_delta = vector_build(context, pg, obj, operation, values, 3)
         except:
@@ -920,7 +918,7 @@ def extrude_geometry(context, pg, operation, mode, obj, bm, values):
         context.window_manager.popup_menu(oops, title="Error", icon="ERROR")
         return
     # Delta/Relative Coordinates
-    if mode == "d":
+    if mode in {"d", "n"}:
         try:
             vector_delta = vector_build(context, pg, obj, operation, values, 3)
         except:
@@ -947,7 +945,7 @@ def extrude_geometry(context, pg, operation, mode, obj, bm, values):
     faces_extr = [f for f in geom_extr if isinstance(f, bmesh.types.BMFace)]
     del ret
 
-    if pg.plane == "LO" and mode == "d":
+    if pg.plane == "LO" and mode in {"d", "n"}:
         vector_delta = view_coords(vector_delta.x, vector_delta.y, vector_delta.z)
     elif pg.plane == "LO" and mode == "i":
         vector_delta = view_dir(pg.distance, pg.angle)
@@ -979,7 +977,7 @@ def duplicate_geometry(context, pg, operation, mode, obj, bm, values):
         context.window_manager.popup_menu(oops, title="Error", icon="ERROR")
         return
     # Delta/Relative Coordinates
-    if mode == "d":
+    if mode in {"d", "n"}:
         try:
             vector_delta = vector_build(context, pg, obj, operation, values, 3)
         except:
@@ -1006,7 +1004,7 @@ def duplicate_geometry(context, pg, operation, mode, obj, bm, values):
     faces_dupe = [f for f in geom_dupe if isinstance(f, bmesh.types.BMFace)]
     del ret
 
-    if pg.plane == "LO" and mode == "d":
+    if pg.plane == "LO" and mode in  {"d", "n"}:
         vector_delta = view_coords(vector_delta.x, vector_delta.y, vector_delta.z)
     elif pg.plane == "LO" and mode == "i":
         vector_delta = view_dir(pg.distance, pg.angle)
@@ -1045,7 +1043,8 @@ def fillet_geometry(context, pg, mode, obj, bm, verts, values):
     # Note that passing an empty parameter results in that parameter being seen as "0"
     # _offset <= 0 is ignored since a bevel/fillet radius must be > 0 to make sense
     _offset = float(values[0])
-    _segments = float(values[1])
+    # Force _segments to an integer (bug fix T95442)
+    _segments = int(float(values[1]))
     if _segments < 1:
         _segments = 1   # This is a single, flat segment (ignores profile)
     _profile = float(values[2])
